==> common-spring-autoconfig-3.6.3-sources.jar: net/wicp/tams/common/spring/autoconfig/schema/AnnotationRegistrar.java <==
package net.wicp.tams.common.spring.autoconfig.schema;

import org.springframework.beans.factory.support.BeanDefinitionRegistry;
import org.springframework.beans.factory.support.RootBeanDefinition;
import org.springframework.context.annotation.ImportBeanDefinitionRegistrar;
import org.springframework.core.type.AnnotationMetadata;
import org.springframework.core.type.StandardClassMetadata;
import org.springframework.util.MultiValueMap;

import net.wicp.tams.common.apiext.StringUtil;
import net.wicp.tams.common.spring.autoconfig.beans.AnnotationBean;

public class AnnotationRegistrar implements ImportBeanDefinitionRegistrar {

	@Override
	public void registerBeanDefinitions(AnnotationMetadata importingClassMetadata, BeanDefinitionRegistry registry) {
		MultiValueMap<String, Object> allAnnotationAttributes = importingClassMetadata
				.getAllAnnotationAttributes("net.wicp.tams.common.spring.autoconfig.annotation.EnableTams");
		String packages = String.valueOf(allAnnotationAttributes.getFirst("packages"));
		String mainpackage = ((StandardClassMetadata) importingClassMetadata).getIntrospectedClass().getPackage()
				.getName();
		if (StringUtil.isNull(packages)) {
			packages = mainpackage;
		} else if (!packages.contains(mainpackage)) {
			packages += "," + mainpackage;
		}
		RootBeanDefinition rootBeanDefinition = new RootBeanDefinition();
		rootBeanDefinition.setBeanClass(AnnotationBean.class);
		rootBeanDefinition.setLazyInit(false);
		rootBeanDefinition.getPropertyValues().addPropertyValue("annotationPackage", packages);
		String generatedBeanName = AnnotationBean.class.getName();
		registry.registerBeanDefinition(generatedBeanName, rootBeanDefinition);
	}

}

==> common-spring-autoconfig-3.6.14-sources.jar: net/wicp/tams/common/spring/autoconfig/schema/AnnotationRegistrar.java <==
package net.wicp.tams.common.spring.autoconfig.schema;

import org.springframework.beans.factory.support.BeanDefinitionRegistry;
import org.springframework.beans.factory.support.RootBeanDefinition;
import org.springframework.context.annotation.ImportBeanDefinitionRegistrar;
import org.springframework.core.type.AnnotationMetadata;
import org.springframework.core.type.StandardClassMetadata;
import org.springframework.util.MultiValueMap;

import net.wicp.tams.common.Conf;
import net.wicp.tams.common.apiext.StringUtil;
import net.wicp.tams.common.spring.autoconfig.beans.AnnotationBean;

public class AnnotationRegistrar implements ImportBeanDefinitionRegistrar {

	@Override
	public void registerBeanDefinitions(AnnotationMetadata importingClassMetadata, BeanDefinitionRegistry registry) {
		MultiValueMap<String, Object> allAnnotationAttributes = importingClassMetadata
				.getAllAnnotationAttributes("net.wicp.tams.common.spring.autoconfig.annotation.EnableTams");

		String springconfpres = String.valueOf(allAnnotationAttributes.getFirst("springconfpres"));
		if (StringUtil.isNotNull(springconfpres)) {
			Conf.overProp("common.spring.autoconfig.addPre", springconfpres);
		}

		String packages = String.valueOf(allAnnotationAttributes.getFirst("packages"));
		String mainpackage = ((StandardClassMetadata) importingClassMetadata).getIntrospectedClass().getPackage()
				.getName();
		if (StringUtil.isNull(packages)) {
			packages = mainpackage;
		} else if (!packages.contains(mainpackage)) {
			packages += "," + mainpackage;
		}
		RootBeanDefinition rootBeanDefinition = new RootBeanDefinition();
		rootBeanDefinition.setBeanClass(AnnotationBean.class);
		rootBeanDefinition.setLazyInit(false);
		rootBeanDefinition.getPropertyValues().addPropertyValue("annotationPackage", packages);
		String generatedBeanName = AnnotationBean.class.getName();
		registry.registerBeanDefinition(generatedBeanName, rootBeanDefinition);
	}

}
